//package org.dromara.system.controller.room;
//
//import java.util.List;
//
//import lombok.RequiredArgsConstructor;
//import jakarta.servlet.http.HttpServletResponse;
//import jakarta.validation.constraints.*;
//import cn.dev33.satoken.annotation.SaCheckPermission;
//import org.springframework.web.bind.annotation.*;
//import org.springframework.validation.annotation.Validated;
//import org.dromara.common.idempotent.annotation.RepeatSubmit;
//import org.dromara.common.log.annotation.Log;
//import org.dromara.common.web.core.BaseController;
//import org.dromara.common.mybatis.core.page.PageQuery;
//import org.dromara.common.core.domain.R;
//import org.dromara.common.core.validate.AddGroup;
//import org.dromara.common.core.validate.EditGroup;
//import org.dromara.common.log.enums.BusinessType;
//import org.dromara.common.excel.utils.ExcelUtil;
//import org.dromara.system.domain.vo.RegionFacilitiesVo;
//import org.dromara.system.domain.bo.RegionFacilitiesBo;
//import org.dromara.system.service.IRegionFacilitiesService;
//import org.dromara.common.mybatis.core.page.TableDataInfo;
//
///**
// * 【请填写功能名称】
// *
// * @author Lion Li
// * @date 2024-12-16
// */
//@Validated
//@RequiredArgsConstructor
//@RestController
//@RequestMapping("/system/facilities")
//public class RegionFacilitiesController extends BaseController {
//
//    private final IRegionFacilitiesService regionFacilitiesService;
//
//    /**
//     * 查询【请填写功能名称】列表
//     */
//    @SaCheckPermission("system:facilities:list")
//    @GetMapping("/list")
//    public TableDataInfo<RegionFacilitiesVo> list(RegionFacilitiesBo bo, PageQuery pageQuery) {
//        return regionFacilitiesService.queryPageList(bo, pageQuery);
//    }
//
//    /**
//     * 导出【请填写功能名称】列表
//     */
//    @SaCheckPermission("system:facilities:export")
//    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(RegionFacilitiesBo bo, HttpServletResponse response) {
//        List<RegionFacilitiesVo> list = regionFacilitiesService.queryList(bo);
//        ExcelUtil.exportExcel(list, "【请填写功能名称】", RegionFacilitiesVo.class, response);
//    }
//
//    /**
//     * 获取【请填写功能名称】详细信息
//     *
//     * @param regionId 主键
//     */
//    @SaCheckPermission("system:facilities:query")
//    @GetMapping("/{regionId}")
//    public R<RegionFacilitiesVo> getInfo(@NotNull(message = "主键不能为空")
//                                     @PathVariable String regionId) {
//        return R.ok(regionFacilitiesService.queryById(regionId));
//    }
//
//    /**
//     * 新增【请填写功能名称】
//     */
//    @SaCheckPermission("system:facilities:add")
//    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
//    @RepeatSubmit()
//    @PostMapping()
//    public R<Void> add(@Validated(AddGroup.class) @RequestBody RegionFacilitiesBo bo) {
//        return toAjax(regionFacilitiesService.insertByBo(bo));
//    }
//
//    /**
//     * 修改【请填写功能名称】
//     */
//    @SaCheckPermission("system:facilities:edit")
//    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
//    @RepeatSubmit()
//    @PutMapping()
//    public R<Void> edit(@Validated(EditGroup.class) @RequestBody RegionFacilitiesBo bo) {
//        return toAjax(regionFacilitiesService.updateByBo(bo));
//    }
//
//    /**
//     * 删除【请填写功能名称】
//     *
//     * @param regionIds 主键串
//     */
//    @SaCheckPermission("system:facilities:remove")
//    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
//    @DeleteMapping("/{regionIds}")
//    public R<Void> remove(@NotEmpty(message = "主键不能为空")
//                          @PathVariable String[] regionIds) {
//        return toAjax(regionFacilitiesService.deleteWithValidByIds(List.of(regionIds), true));
//    }
//}
